@@ -6,5 +6,5 @@
 /* in the file PATENTS.  All contributing project authors may */
 /* be found in the AUTHORS file in the root of the source tree. */
 #include "vpx/vpx_codec.h"
-static const char* const cfg = "--prefix=/usr --target=x86-win32-gcc --enable-vp9-decoder --enable-vp9-encoder --enable-vp10-decoder --enable-vp10-encoder --enable-experimental --enable-spatial-svc --disable-install-srcs --size-limit=16384x16384";
+static const char* const cfg = "--prefix=/usr --target=x86_64-win64-gcc --enable-vp9-decoder --enable-vp9-encoder --enable-vp9-highbitdepth --enable-experimental --enable-spatial-svc --disable-install-srcs --size-limit=16384x16384";
 const char *vpx_codec_build_config(void) {return cfg;}
